# Changelog

---

## Changes in version 0.5 (YYYY/MM/DD)

- TBD

## Changes in version 0.4 (2025/01/09)

- Added support for `MongoDBRecordManager`.
- Added support for `MongoDBLoader`.
- Added support for `numpy 2.0`.
- Added zizmor GitHub Actions security scanning.
- Added local LLM support for testing.

## Changes in version 0.3 (2024/12/13)

- Added support for `MongoDBAtlasParentDocumentRetriever`.
- Migrated to https://github.com/langchain-ai/langchain-mongodb.

## Changes in version 0.2 (2024/09/13)

- Added support for `MongoDBAtlasFullTextSearchRetriever` and `MongoDBAtlasHybridSearchRetriever`.

## Changes in version 0.1 (2024/02/29)

- Initial release, added support for `MongoDBAtlasVectorSearch`.
